package betterquesting.network.handlers;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.events.DatabaseEvent;
import betterquesting.api.network.QuestingPacket;
import betterquesting.api.questing.IQuestLine;
import betterquesting.api2.utils.Tuple2;
import betterquesting.core.BetterQuesting;
import betterquesting.handlers.SaveLoadHandler;
import betterquesting.network.PacketSender;
import betterquesting.network.PacketTypeRegistry;
import betterquesting.questing.QuestLineDatabase;
import com.mojang.realmsclient.gui.ChatFormatting;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.common.MinecraftForge;
import org.apache.logging.log4j.Level;

/* loaded from: betterquesting_network_handlers.jar:betterquesting/network/handlers/NetChapterEdit.class */
public class NetChapterEdit {
    private static final ResourceLocation ID_NAME = new ResourceLocation("betterquesting:chapter_edit");

    public static void registerHandler() {
        PacketTypeRegistry.INSTANCE.registerServerHandler(ID_NAME, NetChapterEdit::onServer);
        if (BetterQuesting.proxy.isClient()) {
            PacketTypeRegistry.INSTANCE.registerClientHandler(ID_NAME, NetChapterEdit::onClient);
        }
    }

    @SideOnly(Side.CLIENT)
    public static void sendEdit(NBTTagCompound payload) {
        PacketSender.INSTANCE.sendToServer(new QuestingPacket(ID_NAME, payload));
    }

    private static void onServer(Tuple2<NBTTagCompound, EntityPlayerMP> message) {
        EntityPlayerMP sender = (EntityPlayerMP) message.func_76340_b();
        MinecraftServer server = sender.field_71133_b;
        if (server == null) {
            return;
        }
        boolean isOP = server.func_71203_ab().func_152596_g(sender.func_146103_bH());
        if (!isOP) {
            BetterQuesting.logger.log(Level.WARN, "Player " + sender.func_70005_c_() + " (UUID:" + QuestingAPI.getQuestingUUID(sender) + ") tried to edit chapters without OP permissions!");
            sender.func_146105_b(new ChatComponentText(ChatFormatting.RED + "You need to be OP to edit quests!"));
            return;
        }
        NBTTagCompound tag = (NBTTagCompound) message.func_76341_a();
        int action = !((NBTTagCompound) message.func_76341_a()).func_150297_b("action", 99) ? -1 : ((NBTTagCompound) message.func_76341_a()).func_74762_e("action");
        switch (action) {
            case 0:
                editChapters(tag.func_150295_c("data", 10));
                return;
            case 1:
                deleteChapters(tag.func_74759_k("chapterIDs"));
                return;
            case 2:
                reorderChapters(tag.func_74759_k("chapterIDs"));
                return;
            case 3:
                createChapters(tag.func_150295_c("data", 10));
                return;
            default:
                BetterQuesting.logger.log(Level.ERROR, "Invalid chapter edit action '" + action + "'. Full payload:\n" + ((NBTTagCompound) message.func_76341_a()).toString());
                return;
        }
    }

    private static void editChapters(NBTTagList data) {
        int[] ids = new int[data.func_74745_c()];
        for (int i = 0; i < data.func_74745_c(); i++) {
            NBTTagCompound entry = data.func_150305_b(i);
            int chapterID = entry.func_74762_e("chapterID");
            ids[i] = chapterID;
            IQuestLine chapter = (IQuestLine) QuestLineDatabase.INSTANCE.getValue(chapterID);
            if (chapter != null) {
                chapter.readFromNBT(entry.func_74775_l("config"), false);
            }
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NetChapterSync.sendSync(null, ids);
    }

    private static void deleteChapters(int[] chapterIDs) {
        for (int id : chapterIDs) {
            QuestLineDatabase.INSTANCE.removeID(id);
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74783_a("chapterIDs", chapterIDs);
        payload.func_74768_a("action", 1);
        PacketSender.INSTANCE.sendToAll(new QuestingPacket(ID_NAME, payload));
    }

    private static void reorderChapters(int[] chapterIDs) {
        for (int n = 0; n < chapterIDs.length; n++) {
            QuestLineDatabase.INSTANCE.setOrderIndex(chapterIDs[n], n);
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74783_a("chapterIDs", chapterIDs);
        payload.func_74768_a("action", 2);
        PacketSender.INSTANCE.sendToAll(new QuestingPacket(ID_NAME, payload));
    }

    private static void createChapters(NBTTagList data) {
        int[] ids = new int[data.func_74745_c()];
        for (int i = 0; i < data.func_74745_c(); i++) {
            NBTTagCompound entry = data.func_150305_b(i);
            int chapterID = entry.func_150297_b("chapterID", 99) ? entry.func_74762_e("chapterID") : -1;
            if (chapterID < 0) {
                chapterID = QuestLineDatabase.INSTANCE.nextID();
            }
            ids[i] = chapterID;
            IQuestLine chapter = (IQuestLine) QuestLineDatabase.INSTANCE.getValue(chapterID);
            if (chapter == null) {
                chapter = QuestLineDatabase.INSTANCE.createNew(chapterID);
            }
            if (entry.func_150297_b("config", 10)) {
                chapter.readFromNBT(entry.func_74775_l("config"), false);
            }
        }
        SaveLoadHandler.INSTANCE.markDirty();
        NetChapterSync.sendSync(null, ids);
    }

    @SideOnly(Side.CLIENT)
    private static void onClient(NBTTagCompound message) {
        int action = !message.func_150297_b("action", 99) ? -1 : message.func_74762_e("action");
        switch (action) {
            case 1:
                for (int id : message.func_74759_k("chapterIDs")) {
                    QuestLineDatabase.INSTANCE.removeID(id);
                }
                MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.CHAPTER));
                return;
            case 2:
                int[] chapterIDs = message.func_74759_k("chapterIDs");
                for (int n = 0; n < chapterIDs.length; n++) {
                    QuestLineDatabase.INSTANCE.setOrderIndex(chapterIDs[n], n);
                }
                MinecraftForge.EVENT_BUS.post(new DatabaseEvent.Update(DatabaseEvent.DBType.CHAPTER));
                return;
            default:
                return;
        }
    }
}
